==> kleopatra-16.04.2.tar.xz: kleopatra-16.04.2/src/crypto/gui/encryptemailwizard.cpp <==
/* -*- mode: c++; c-basic-offset:4 -*-
    crypto/gui/encryptemailwizard.cpp

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include <config-kleopatra.h>

#include "encryptemailwizard.h"
#include <crypto/gui/resolverecipientspage.h>

#include <KLocalizedString>

using namespace Kleo;
using namespace Kleo::Crypto;
using namespace Kleo::Crypto::Gui;

class EncryptEMailWizard::Private
{
public:
    Private() : m_quickMode(false) {}
    bool m_quickMode;
};

EncryptEMailWizard::EncryptEMailWizard(QWidget *parent, Qt::WindowFlags flags) : SignEncryptWizard(parent, flags), d(new Private)
{
    setWindowTitle(i18n("Encrypt Mail Message"));
    std::vector<int> pageOrder;
    pageOrder.push_back(ResolveRecipientsPage);
    pageOrder.push_back(ResultPage);
    setPageOrder(pageOrder);
    setCommitPage(SignEncryptWizard::ResolveRecipientsPage);
}

EncryptEMailWizard::~EncryptEMailWizard()
{

}

bool EncryptEMailWizard::quickMode() const
{
    return d->m_quickMode;
}

void EncryptEMailWizard::setQuickMode(bool quick)
{
    if (quick == d->m_quickMode) {
        return;
    }
    d->m_quickMode = quick;
    signerResolvePage()->setAutoAdvance(quick);
    resolveRecipientsPage()->setAutoAdvance(quick);
    setKeepResultPageOpenWhenDone(!quick);
}

#include "encryptemailwizard.h"

==> kleopatra_19.12.3.orig.tar.xz: kleopatra-19.12.3/src/crypto/gui/encryptemailwizard.cpp <==
/* -*- mode: c++; c-basic-offset:4 -*-
    crypto/gui/encryptemailwizard.cpp

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include <config-kleopatra.h>

#include "encryptemailwizard.h"
#include <crypto/gui/resolverecipientspage.h>

#include <KLocalizedString>

using namespace Kleo;
using namespace Kleo::Crypto;
using namespace Kleo::Crypto::Gui;

class EncryptEMailWizard::Private
{
public:
    Private() : m_quickMode(false) {}
    bool m_quickMode;
};

EncryptEMailWizard::EncryptEMailWizard(QWidget *parent, Qt::WindowFlags flags) : SignEncryptWizard(parent, flags), d(new Private)
{
    setWindowTitle(i18nc("@title:window", "Encrypt Mail Message"));
    std::vector<int> pageOrder;
    pageOrder.push_back(ResolveRecipientsPage);
    pageOrder.push_back(ResultPage);
    setPageOrder(pageOrder);
    setCommitPage(SignEncryptWizard::ResolveRecipientsPage);
}

EncryptEMailWizard::~EncryptEMailWizard()
{

}

bool EncryptEMailWizard::quickMode() const
{
    return d->m_quickMode;
}

void EncryptEMailWizard::setQuickMode(bool quick)
{
    if (quick == d->m_quickMode) {
        return;
    }
    d->m_quickMode = quick;
    signerResolvePage()->setAutoAdvance(quick);
    resolveRecipientsPage()->setAutoAdvance(quick);
    setKeepResultPageOpenWhenDone(!quick);
}

#include "encryptemailwizard.h"
